@@ -27,8 +27,8 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef	_SYS_TREE_H_
-#define	_SYS_TREE_H_
+#ifndef LIBBSD_SYS_TREE_H
+#define LIBBSD_SYS_TREE_H
 
 #include <sys/cdefs.h>
 
@@ -762,4 +762,4 @@ name##_RB_MINMAX(struct name *head, int val)				\
 	    ((x) != NULL) && ((y) = name##_RB_PREV(x), (x) != NULL);	\
 	     (x) = (y))
 
-#endif	/* _SYS_TREE_H_ */
+#endif /* LIBBSD_SYS_TREE_H */
